#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IS_NOT_EQUAL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IS_NOT_EQUAL_HPP_INCLUDED

#include <boost/simd/operator/include/functions/simd/is_not_equal.hpp>

#endif
